RunCallback

Type Alias RunCallback 

pub type RunCallback = Arc<dyn Fn(RunEvent) + Send + Sync>;
Callback a harness invokes for each run event. Arc<dyn Fn> is Clone + Send + Sync, so it can be handed to the multiple reader threads a process-backed harness uses without the trait method needing to be generic.

Aliased Type

pub struct RunCallback { /* private fields */ }